package net.minecraft.client.gui;

import net.minecraft.game.entity.Entity;
import net.minecraft.client.renderer.entity.RenderManager;
import net.minecraft.client.renderer.RenderHelper;
import net.minecraft.client.renderer.RenderEngine;
import org.lwjgl.opengl.GL11;
import net.minecraft.game.recipe.CraftingManager;
import net.minecraft.game.item.ItemStack;
import net.minecraft.client.inventory.InventoryCraftResult;
import net.minecraft.client.inventory.IInventory;
import net.minecraft.client.inventory.InventoryCrafting;

public class GuiInventory extends GuiContainer {
    private InventoryCrafting inventoryCrafting;
    private IInventory iInventory;
    private double xSize_lo;
    private double ySize_lo;
    
    public GuiInventory(final IInventory b) {
        this.inventoryCrafting = new InventoryCrafting(this, 2, 2);
        this.iInventory = new InventoryCraftResult();
        this.allowUserInput = true;
        this.inventorySlots.add(new SlotCrafting(this, this.inventoryCrafting, this.iInventory, 0, 144, 36));
        for (int i = 0; i < 2; ++i) {
            for (int j = 0; j < 2; ++j) {
                this.inventorySlots.add(new Slot(this, this.inventoryCrafting, j + (i << 1), 88 + j * 18, 26 + i * 18));
            }
        }
        for (int i = 0; i < 4; ++i) {
            final int j = i;
            this.inventorySlots.add(new SlotArmor(this, this, b, b.getSizeInventory() - 1 - i, 8, 8 + i * 18, j));
        }
        for (int i = 0; i < 3; ++i) {
            for (int j = 0; j < 9; ++j) {
                this.inventorySlots.add(new Slot(this, b, j + (i + 1) * 9, 8 + j * 18, 84 + i * 18));
            }
        }
        for (int i = 0; i < 9; ++i) {
            this.inventorySlots.add(new Slot(this, b, i, 8 + i * 18, 142));
        }
    }
    
    @Override
    public final void onGuiClosed() {
        super.onGuiClosed();
        for (int i = 0; i < this.inventoryCrafting.getSizeInventory(); ++i) {
            final ItemStack stackInSlot;
            if ((stackInSlot = this.inventoryCrafting.getStackInSlot(i)) != null) {
                this.mc.thePlayer.dropPlayerItem(stackInSlot);
            }
        }
    }
    
    @Override
    public final void guiCraftingItemsCheck() {
        final int[] arr = new int[9];
        for (int i = 0; i < 3; ++i) {
            for (int j = 0; j < 3; ++j) {
                int itemID = -1;
                final ItemStack stackInSlot;
                if (i < 2 && j < 2 && (stackInSlot = this.inventoryCrafting.getStackInSlot(i + (j << 1))) != null) {
                    itemID = stackInSlot.itemID;
                }
                arr[i + j * 3] = itemID;
            }
        }
        this.iInventory.setInventorySlotContents(0, CraftingManager.getInstance().findMatchingRecipe(arr));
    }
    
    @Override
    protected void drawGuiContainerForegroundLayer() {
        this.fontRenderer.drawString("Crafting", 86, 16, 4210752);
    }
    
    @Override
    public final void drawScreen(final int xSize_lo, final int ySize_lo, final double double3) {
        super.drawScreen(xSize_lo, ySize_lo, double3);
        this.xSize_lo = (double)xSize_lo;
        this.ySize_lo = (double)ySize_lo;
    }
    
    @Override
    protected void drawGuiContainerBackgroundLayer() {
        int texture = this.mc.renderEngine.getTexture("/gui/inventory.png");
        GL11.glColor4d(1.0f, 1.0f, 1.0f, 1.0f);
        RenderEngine.bindTexture(texture);
        texture = (this.width - this.xSize) / 2;
        final int integer2 = (this.height - this.ySize) / 2;
        this.drawTexturedModalRect(texture, integer2, 0, 0, this.xSize, this.ySize);
        GL11.glEnable(2977);
        GL11.glEnable(2903);
        GL11.glPushMatrix();
        GL11.glTranslated((double)(texture + 51), (double)(integer2 + 75), 50.0f);
        GL11.glScaled(-30.0f, 30.0f, 30.0f);
        GL11.glRotated(180.0f, 0.0f, 0.0f, 1.0f);
        final double renderYawOffset = this.mc.thePlayer.renderYawOffset;
        final double rotationYaw = this.mc.thePlayer.rotationYaw;
        final double rotationPitch = this.mc.thePlayer.rotationPitch;
        final double n = texture + 51 - this.xSize_lo;
        final double n2 = integer2 + 75 - 50 - this.ySize_lo;
        GL11.glRotated(135.0f, 0.0f, 1.0f, 0.0f);
        RenderHelper.enableStandardItemLighting();
        GL11.glRotated(-135.0f, 0.0f, 1.0f, 0.0f);
        GL11.glRotated(-(double)Math.atan((double)(n2 / 40.0f)) * 20.0f, 1.0f, 0.0f, 0.0f);
        this.mc.thePlayer.renderYawOffset = (double)Math.atan((double)(n / 40.0f)) * 20.0f;
        this.mc.thePlayer.rotationYaw = (double)Math.atan((double)(n / 40.0f)) * 40.0f;
        this.mc.thePlayer.rotationPitch = -(double)Math.atan((double)(n2 / 40.0f)) * 20.0f;
        GL11.glTranslated(0.0f, this.mc.thePlayer.yOffset, 0.0f);
        RenderManager.instance.renderEntityWithPosYaw(this.mc.thePlayer, 0.0f, 0.0f, 0.0f, 0.0f, 1.0f);
        this.mc.thePlayer.renderYawOffset = renderYawOffset;
        this.mc.thePlayer.rotationYaw = rotationYaw;
        this.mc.thePlayer.rotationPitch = rotationPitch;
        GL11.glPopMatrix();
        RenderHelper.disableStandardItemLighting();
        GL11.glDisable(2977);
    }
}
