package net.minecraft.client.particle;

import com.nbt.NBTTagCompound;
import net.minecraft.client.renderer.Tessellator;
import net.minecraft.game.MathHelper;
import net.minecraft.game.level.World;
import net.minecraft.game.entity.Entity;

public class EntityFX extends Entity {
    protected double motionX1;
    protected double motionY1;
    protected double motionZ1;
    protected int particleTextureIndex;
    protected double particleTextureJitterX;
    protected double particleTextureJitterY;
    protected int particleAge;
    protected int particleMaxAge;
    protected double particleScale;
    protected double particleGravity;
    protected double particleRed;
    protected double particleGreen;
    protected double particleBlue;
    
    public EntityFX(final World world, double double2, final double double3, final double double4, final double double5, final double double6, final double double7) {
        super(world);
        this.particleAge = 0;
        this.particleMaxAge = 0;
        this.setSize(0.2f, 0.2f);
        this.yOffset = this.height / 2.0f;
        this.setPosition(double2, double3, double4);
        final double particleRed = 1.0f;
        this.particleBlue = particleRed;
        this.particleGreen = particleRed;
        this.particleRed = particleRed;
        this.motionX1 = double5 + (double)(Math.random() * 2.0 - 1.0) * 0.4f;
        this.motionY1 = double6 + (double)(Math.random() * 2.0 - 1.0) * 0.4f;
        this.motionZ1 = double7 + (double)(Math.random() * 2.0 - 1.0) * 0.4f;
        final double n = (double)(Math.random() + Math.random() + 1.0) * 0.15f;
        double2 = MathHelper.sqrt_double(this.motionX1 * this.motionX1 + this.motionY1 * this.motionY1 + this.motionZ1 * this.motionZ1);
        this.motionX1 = this.motionX1 / double2 * n * 0.4f;
        this.motionY1 = this.motionY1 / double2 * n * 0.4f + 0.1f;
        this.motionZ1 = this.motionZ1 / double2 * n * 0.4f;
        this.particleTextureJitterX = this.rand.nextDouble() * 3.0f;
        this.particleTextureJitterY = this.rand.nextDouble() * 3.0f;
        this.particleScale = (this.rand.nextDouble() * 0.5f + 0.5f) * 2.0f;
        this.particleMaxAge = (int)(4.0f / (this.rand.nextDouble() * 0.9f + 0.1f));
        this.particleAge = 0;
        this.entityWalks = false;
    }
    
    public final EntityFX multiplyVelocity(final double double1) {
        this.motionX1 *= 0.2f;
        this.motionY1 = (this.motionY1 - 0.1f) * 0.2f + 0.1f;
        this.motionZ1 *= 0.2f;
        return this;
    }
    
    public final EntityFX multipleParticleScaleBy(final double double1) {
        this.setSize(0.120000005f, 0.120000005f);
        this.particleScale *= 0.6f;
        return this;
    }
    
    @Override
    public void onEntityUpdate() {
        this.prevPosX = this.posX;
        this.prevPosY = this.posY;
        this.prevPosZ = this.posZ;
        if (this.particleAge++ >= this.particleMaxAge) {
            this.setEntityDead();
        }
        this.motionY1 -= (double)(0.04 * this.particleGravity);
        this.moveEntity(this.motionX1, this.motionY1, this.motionZ1);
        this.motionX1 *= 0.98f;
        this.motionY1 *= 0.98f;
        this.motionZ1 *= 0.98f;
        if (this.onGround) {
            this.motionX1 *= 0.7f;
            this.motionZ1 *= 0.7f;
        }
    }
    
    public void renderParticle(final Tessellator tessellator, double double2, final double double3, final double double4, final double double5, final double double6, final double double7) {
        final double n2;
        final double n = (n2 = this.particleTextureIndex % 16 / 16.0f) + 0.0624375f;
        final double n4;
        final double n3 = (n4 = this.particleTextureIndex / 16 / 16.0f) + 0.0624375f;
        final double n5 = 0.1f * this.particleScale;
        final double n6 = this.prevPosX + (this.posX - this.prevPosX) * double2;
        final double n7 = this.prevPosY + (this.posY - this.prevPosY) * double2;
        final double n8 = this.prevPosZ + (this.posZ - this.prevPosZ) * double2;
        double2 = this.getEntityBrightness(double2);
        tessellator.setColorOpaque_F(this.particleRed * double2, this.particleGreen * double2, this.particleBlue * double2);
        tessellator.addVertexWithUV(n6 - double3 * n5 - double6 * n5, n7 - double4 * n5, n8 - double5 * n5 - double7 * n5, n2, n3);
        tessellator.addVertexWithUV(n6 - double3 * n5 + double6 * n5, n7 + double4 * n5, n8 - double5 * n5 + double7 * n5, n2, n4);
        tessellator.addVertexWithUV(n6 + double3 * n5 + double6 * n5, n7 + double4 * n5, n8 + double5 * n5 + double7 * n5, n, n4);
        tessellator.addVertexWithUV(n6 + double3 * n5 - double6 * n5, n7 - double4 * n5, n8 + double5 * n5 - double7 * n5, n, n3);
    }
    
    public int getFXLayer() {
        return 0;
    }
    
    @Override
    protected final void writeEntityToNBT(final NBTTagCompound nbtTagCompound) {
    }
    
    @Override
    protected final String getEntityString() {
        return null;
    }
    
    @Override
    protected final void readEntityFromNBT(final NBTTagCompound nbtTagCompound) {
    }
}
