package net.minecraft.client.renderer;

import org.lwjgl.opengl.GL11;
import net.minecraft.game.block.Material;
import net.minecraft.game.block.Block;
import net.minecraft.game.level.World;

public final class RenderBlocks {
    private World blockAccess;
    private int overrideBlockTexture;
    private boolean flipTexture;
    
    public RenderBlocks(final World world) {
        this.overrideBlockTexture = -1;
        this.flipTexture = false;
        this.blockAccess = world;
    }
    
    public RenderBlocks() {
        this.overrideBlockTexture = -1;
        this.flipTexture = false;
    }
    
    public final void renderBlockUsingTexture(final Block block, final int integer2, final int integer3, final int integer4, final int integer5) {
        this.overrideBlockTexture = integer5;
        this.renderBlockByRenderType(block, integer2, integer3, integer4);
        this.overrideBlockTexture = -1;
    }
    
    public final void renderBlockAllFaces(final Block block, final int integer2, final int integer3, final int integer4) {
        this.flipTexture = true;
        this.renderBlockByRenderType(block, integer2, integer3, integer4);
        this.flipTexture = false;
    }
    
    public final boolean renderBlockByRenderType(final Block block, int integer2, int integer3, int integer4) {
        int renderType;
        if ((renderType = block.getRenderType()) == 0) {
            final int n = integer2;
            final int n2 = integer3;
            renderType = integer4;
            integer4 = n2;
            integer3 = n;
            final Tessellator instance = Tessellator.instance;
            boolean b = false;
            if (this.flipTexture || block.shouldSideBeRendered(this.blockAccess, integer3, integer4 - 1, renderType, 0)) {
                double double4 = block.getBlockBrightness(this.blockAccess, integer3, integer4 - 1, renderType);
                if (Block.lightValue[block.blockID] > 0) {
                    double4 = 1.0f;
                }
                instance.setColorOpaque_F(0.5f * double4, 0.5f * double4, 0.5f * double4);
                this.renderBlockBottom(block, (double) (integer3 & 0xF), (double) (integer4 & 0xF), (double) (renderType & 0xF), block.getBlockTexture(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, 0));
                b = true;
            }
            if (this.flipTexture || block.shouldSideBeRendered(this.blockAccess, integer3, integer4 + 1, renderType, 1)) {
                double double4 = block.getBlockBrightness(this.blockAccess, integer3, integer4 + 1, renderType);
                if (Block.lightValue[block.blockID] > 0) {
                    double4 = 1.0f;
                }
                instance.setColorOpaque_F(double4 * 1.0f, double4 * 1.0f, double4 * 1.0f);
                this.renderBlockTop(block, (double) (integer3 & 0xF), (double) (integer4 & 0xF), (double) (renderType & 0xF), block.getBlockTexture(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, 1));
                b = true;
            }
            if (this.flipTexture || block.shouldSideBeRendered(this.blockAccess, integer3, integer4, renderType - 1, 2)) {
                double double4 = block.getBlockBrightness(this.blockAccess, integer3, integer4, renderType - 1);
                if (Block.lightValue[block.blockID] > 0) {
                    double4 = 1.0f;
                }
                instance.setColorOpaque_F(0.8f * double4, 0.8f * double4, 0.8f * double4);
                this.renderBlockNorth(block, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, block.getBlockTexture(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, 2));
                b = true;
            }
            if (this.flipTexture || block.shouldSideBeRendered(this.blockAccess, integer3, integer4, renderType + 1, 3)) {
                double double4 = block.getBlockBrightness(this.blockAccess, integer3, integer4, renderType + 1);
                if (Block.lightValue[block.blockID] > 0) {
                    double4 = 1.0f;
                }
                instance.setColorOpaque_F(0.8f * double4, 0.8f * double4, 0.8f * double4);
                this.renderBlockSouth(block, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, block.getBlockTexture(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, 3));
                b = true;
            }
            if (this.flipTexture || block.shouldSideBeRendered(this.blockAccess, integer3 - 1, integer4, renderType, 4)) {
                double double4 = block.getBlockBrightness(this.blockAccess, integer3 - 1, integer4, renderType);
                if (Block.lightValue[block.blockID] > 0) {
                    double4 = 1.0f;
                }
                instance.setColorOpaque_F(0.6f * double4, 0.6f * double4, 0.6f * double4);
                this.renderBlockWest(block, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, block.getBlockTexture(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, 4));
                b = true;
            }
            if (this.flipTexture || block.shouldSideBeRendered(this.blockAccess, integer3 + 1, integer4, renderType, 5)) {
                double double4 = block.getBlockBrightness(this.blockAccess, integer3 + 1, integer4, renderType);
                if (Block.lightValue[block.blockID] > 0) {
                    double4 = 1.0f;
                }
                instance.setColorOpaque_F(0.6f * double4, 0.6f * double4, 0.6f * double4);
                this.renderBlockEast(block, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, block.getBlockTexture(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, 5));
                b = true;
            }
            return b;
        }
        if (renderType == 4) {
            final int n3 = integer2;
            final int n4 = integer3;
            renderType = integer4;
            integer4 = n4;
            integer3 = n3;
            final Tessellator instance2 = Tessellator.instance;
            boolean b = false;
            final double double4 = block.minY;
            final double maxY = block.maxY;
            block.maxY = maxY - this.materialNotWater(integer3 & 0xF, integer4 & 0xF, renderType & 0xF);
            if (this.flipTexture || block.shouldSideBeRendered(this.blockAccess, integer3, integer4 - 1, renderType, 0)) {
                final double n5 = block.getBlockBrightness(this.blockAccess, integer3, integer4 - 1, renderType);
                instance2.setColorOpaque_F(0.5f * n5, 0.5f * n5, 0.5f * n5);
                this.renderBlockBottom(block, (double) (integer3 & 0xF), (double) (integer4 & 0xF), (double) (renderType & 0xF), block.getBlockTextureFromSide(0));
                b = true;
            }
            if (this.flipTexture || block.shouldSideBeRendered(this.blockAccess, integer3, integer4 + 1, renderType, 1)) {
                final double n5 = block.getBlockBrightness(this.blockAccess, integer3, integer4 + 1, renderType);
                instance2.setColorOpaque_F(n5 * 1.0f, n5 * 1.0f, n5 * 1.0f);
                this.renderBlockTop(block, (double) (integer3 & 0xF), (double) (integer4 & 0xF), (double) (renderType & 0xF), block.getBlockTextureFromSide(1));
                b = true;
            }
            block.minY = maxY - this.materialNotWater(integer3 & 0xF, integer4 & 0xF, renderType & 0xF - 1);
            if (this.flipTexture || block.maxY > block.minY || block.shouldSideBeRendered(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF - 1, 2)) {
                final double n5 = block.getBlockBrightness(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF - 1);
                instance2.setColorOpaque_F(0.8f * n5, 0.8f * n5, 0.8f * n5);
                this.renderBlockNorth(block, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, block.getBlockTextureFromSide(2));
                b = true;
            }
            block.minY = maxY - this.materialNotWater(integer3 & 0xF, integer4 & 0xF, renderType & 0xF + 1);
            if (this.flipTexture || block.maxY > block.minY || block.shouldSideBeRendered(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF + 1, 3)) {
                final double n5 = block.getBlockBrightness(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF + 1);
                instance2.setColorOpaque_F(0.8f * n5, 0.8f * n5, 0.8f * n5);
                this.renderBlockSouth(block, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, block.getBlockTextureFromSide(3));
                b = true;
            }
            block.minY = maxY - this.materialNotWater(integer3 - 1, integer4, renderType);
            if (this.flipTexture || block.maxY > block.minY || block.shouldSideBeRendered(this.blockAccess, integer3 - 1, integer4, renderType, 4)) {
                final double n5 = block.getBlockBrightness(this.blockAccess, integer3 - 1, integer4, renderType);
                instance2.setColorOpaque_F(0.6f * n5, 0.6f * n5, 0.6f * n5);
                this.renderBlockWest(block, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, block.getBlockTextureFromSide(4));
                b = true;
            }
            block.minY = maxY - this.materialNotWater(integer3 + 1, integer4, renderType);
            if (this.flipTexture || block.maxY > block.minY || block.shouldSideBeRendered(this.blockAccess, integer3 + 1, integer4, renderType, 5)) {
                final double n5 = block.getBlockBrightness(this.blockAccess, integer3 + 1, integer4, renderType);
                instance2.setColorOpaque_F(0.6f * n5, 0.6f * n5, 0.6f * n5);
                this.renderBlockEast(block, integer3 & 0xF, integer4 & 0xF, renderType & 0xF, block.getBlockTextureFromSide(5));
                b = true;
            }
            block.minY = double4;
            block.maxY = maxY;
            return b;
        }
        if (renderType == 1) {
            final int n6 = integer2;
            final int n7 = integer3;
            renderType = integer4;
            integer4 = n7;
            integer3 = n6;
            final Tessellator instance3 = Tessellator.instance;
            final double n5 = block.getBlockBrightness(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF);
            instance3.setColorOpaque_F(n5, n5, n5);
            this.renderBlockPlant(block, this.blockAccess.getBlockMetadata(integer3 & 0xF, integer4 & 0xF, renderType & 0xF), (double) (integer3 & 0xF), (double) (integer4 & 0xF), (double) (renderType & 0xF));
            return true;
        }
        if (renderType == 6) {
            final int n8 = integer2;
            final int n9 = integer3;
            renderType = integer4;
            integer4 = n9;
            integer3 = n8;
            final Tessellator instance4 = Tessellator.instance;
            final double n5 = block.getBlockBrightness(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF);
            instance4.setColorOpaque_F(n5, n5, n5);
            this.renderBlockCrops(block, this.blockAccess.getBlockMetadata(integer3 & 0xF, integer4 & 0xF, renderType & 0xF), (double)integer3, integer4 - 0.0625f, (double)renderType);
            return true;
        }
        if (renderType == 2) {
            final int n10 = integer2;
            final int n11 = integer3;
            renderType = integer4;
            integer4 = n11;
            integer3 = n10;
            final byte blockMetadata = this.blockAccess.getBlockMetadata(integer3 & 0xF, integer4 & 0xF, renderType & 0xF);
            final Tessellator instance5 = Tessellator.instance;
            double n12 = block.getBlockBrightness(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF);
            if (Block.lightValue[block.blockID] > 0) {
                n12 = 1.0f;
            }
            instance5.setColorOpaque_F(n12, n12, n12);
            if (blockMetadata == 1) {
                this.renderBlockTorch(block, integer3 - 0.099999994f, integer4 + 0.2f, (double)renderType, -0.4f, 0.0f);
            }
            else if (blockMetadata == 2) {
                this.renderBlockTorch(block, integer3 + 0.099999994f, integer4 + 0.2f, (double)renderType, 0.4f, 0.0f);
            }
            else if (blockMetadata == 3) {
                this.renderBlockTorch(block, (double)integer3, integer4 + 0.2f, renderType - 0.099999994f, 0.0f, -0.4f);
            }
            else if (blockMetadata == 4) {
                this.renderBlockTorch(block, (double)integer3, integer4 + 0.2f, renderType + 0.099999994f, 0.0f, 0.4f);
            }
            else {
                this.renderBlockTorch(block, (double) (integer3 & 0xF), (double) (integer4 & 0xF), (double) (renderType & 0xF), 0.0f, 0.0f);
            }
            return true;
        }
        if (renderType == 3) {
            final int n13 = integer2;
            final int n14 = integer3;
            renderType = integer4;
            integer4 = n14;
            integer3 = n13;
            final Tessellator instance6 = Tessellator.instance;
            int n15 = block.getBlockTextureFromSide(0);
            if (this.overrideBlockTexture >= 0) {
                n15 = this.overrideBlockTexture;
            }
            final double n12 = block.getBlockBrightness(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF);
            instance6.setColorOpaque_F(n12, n12, n12);
            integer2 = (n15 & 0xF) << 4;
            final int n16 = n15 & 0xF0;
            double n17 = integer2 / 256.0f;
            double double4 = (integer2 + 15.99f) / 256.0f;
            double maxY = n16 / 256.0f;
            double n5 = (n16 + 15.99f) / 256.0f;
            if (this.blockAccess.isBlockNormalCube(integer3, integer4 - 1, renderType) || Block.fire.canBlockCatchFire(this.blockAccess, integer3, integer4 - 1, renderType)) {
                double n18 = integer3 + 0.5f + 0.2f;
                double n19 = integer3 + 0.5f - 0.2f;
                double n20 = renderType + 0.5f + 0.2f;
                double n21 = renderType + 0.5f - 0.2f;
                double n22 = integer3 + 0.5f - 0.3f;
                double n23 = integer3 + 0.5f + 0.3f;
                double n24 = renderType + 0.5f - 0.3f;
                double n25 = renderType + 0.5f + 0.3f;
                instance6.addVertexWithUV(n22, integer4 + 1.4f, (double)(renderType + 1), double4, maxY);
                instance6.addVertexWithUV(n18, (double)integer4, (double)(renderType + 1), double4, n5);
                instance6.addVertexWithUV(n18, (double)integer4, (double)renderType, n17, n5);
                instance6.addVertexWithUV(n22, integer4 + 1.4f, (double)renderType, n17, maxY);
                instance6.addVertexWithUV(n23, integer4 + 1.4f, (double)renderType, double4, maxY);
                instance6.addVertexWithUV(n19, (double)integer4, (double)renderType, double4, n5);
                instance6.addVertexWithUV(n19, (double)integer4, (double)(renderType + 1), n17, n5);
                instance6.addVertexWithUV(n23, integer4 + 1.4f, (double)(renderType + 1), n17, maxY);
                n17 = integer2 / 256.0f;
                double4 = (integer2 + 15.99f) / 256.0f;
                maxY = (n16 + 16) / 256.0f;
                n5 = (n16 + 15.99f + 16.0f) / 256.0f;
                instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 1.4f, n25, double4, maxY);
                instance6.addVertexWithUV((double)(integer3 + 1), (double)integer4, n21, double4, n5);
                instance6.addVertexWithUV((double)integer3, (double)integer4, n21, n17, n5);
                instance6.addVertexWithUV((double)integer3, integer4 + 1.4f, n25, n17, maxY);
                instance6.addVertexWithUV((double)integer3, integer4 + 1.4f, n24, double4, maxY);
                instance6.addVertexWithUV((double)integer3, (double)integer4, n20, double4, n5);
                instance6.addVertexWithUV((double)(integer3 + 1), (double)integer4, n20, n17, n5);
                instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 1.4f, n24, n17, maxY);
                n18 = integer3 + 0.5f - 0.5f;
                n19 = integer3 + 0.5f + 0.5f;
                n20 = renderType + 0.5f - 0.5f;
                n21 = renderType + 0.5f + 0.5f;
                n22 = integer3 + 0.5f - 0.4f;
                n23 = integer3 + 0.5f + 0.4f;
                n24 = renderType + 0.5f - 0.4f;
                n25 = renderType + 0.5f + 0.4f;
                instance6.addVertexWithUV(n22, integer4 + 1.4f, (double)renderType, n17, maxY);
                instance6.addVertexWithUV(n18, (double)integer4, (double)renderType, n17, n5);
                instance6.addVertexWithUV(n18, (double)integer4, (double)(renderType + 1), double4, n5);
                instance6.addVertexWithUV(n22, integer4 + 1.4f, (double)(renderType + 1), double4, maxY);
                instance6.addVertexWithUV(n23, integer4 + 1.4f, (double)(renderType + 1), n17, maxY);
                instance6.addVertexWithUV(n19, (double)integer4, (double)(renderType + 1), n17, n5);
                instance6.addVertexWithUV(n19, (double)integer4, (double)renderType, double4, n5);
                instance6.addVertexWithUV(n23, integer4 + 1.4f, (double)renderType, double4, maxY);
                n17 = integer2 / 256.0f;
                double4 = (integer2 + 15.99f) / 256.0f;
                maxY = n16 / 256.0f;
                n5 = (n16 + 15.99f) / 256.0f;
                instance6.addVertexWithUV((double)integer3, integer4 + 1.4f, n25, n17, maxY);
                instance6.addVertexWithUV((double)integer3, (double)integer4, n21, n17, n5);
                instance6.addVertexWithUV((double)(integer3 + 1), (double)integer4, n21, double4, n5);
                instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 1.4f, n25, double4, maxY);
                instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 1.4f, n24, n17, maxY);
                instance6.addVertexWithUV((double)(integer3 + 1), (double)integer4, n20, n17, n5);
                instance6.addVertexWithUV((double)integer3, (double)integer4, n20, double4, n5);
                instance6.addVertexWithUV((double)integer3, integer4 + 1.4f, n24, double4, maxY);
            }
            else {
                if ((integer3 + integer4 + renderType & 0x1) == 0x1) {
                    n17 = integer2 / 256.0f;
                    double4 = (integer2 + 15.99f) / 256.0f;
                    maxY = (n16 + 16) / 256.0f;
                    n5 = (n16 + 15.99f + 16.0f) / 256.0f;
                }
                if ((integer3 / 2 + integer4 / 2 + renderType / 2 & 0x1) == 0x1) {
                    final double n20 = double4;
                    double4 = n17;
                    n17 = n20;
                }
                if (Block.fire.canBlockCatchFire(this.blockAccess, integer3 - 1, integer4, renderType)) {
                    instance6.addVertexWithUV(integer3 + 0.2f, integer4 + 1.4f + 0.0625f, (double)(renderType + 1), double4, maxY);
                    instance6.addVertexWithUV((double)integer3, integer4 + 0.0625f, (double)(renderType + 1), double4, n5);
                    instance6.addVertexWithUV((double)integer3, integer4 + 0.0625f, (double)renderType, n17, n5);
                    instance6.addVertexWithUV(integer3 + 0.2f, integer4 + 1.4f + 0.0625f, (double)renderType, n17, maxY);
                    instance6.addVertexWithUV(integer3 + 0.2f, integer4 + 1.4f + 0.0625f, (double)renderType, n17, maxY);
                    instance6.addVertexWithUV((double)integer3, integer4 + 0.0625f, (double)renderType, n17, n5);
                    instance6.addVertexWithUV((double)integer3, integer4 + 0.0625f, (double)(renderType + 1), double4, n5);
                    instance6.addVertexWithUV(integer3 + 0.2f, integer4 + 1.4f + 0.0625f, (double)(renderType + 1), double4, maxY);
                }
                if (Block.fire.canBlockCatchFire(this.blockAccess, integer3 + 1, integer4, renderType)) {
                    instance6.addVertexWithUV(integer3 + 1 - 0.2f, integer4 + 1.4f + 0.0625f, (double)renderType, n17, maxY);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 0.0625f, (double)renderType, n17, n5);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 0.0625f, (double)(renderType + 1), double4, n5);
                    instance6.addVertexWithUV(integer3 + 1 - 0.2f, integer4 + 1.4f + 0.0625f, (double)(renderType + 1), double4, maxY);
                    instance6.addVertexWithUV(integer3 + 1 - 0.2f, integer4 + 1.4f + 0.0625f, (double)(renderType + 1), double4, maxY);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 0.0625f, (double)(renderType + 1), double4, n5);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 0.0625f, (double)renderType, n17, n5);
                    instance6.addVertexWithUV(integer3 + 1 - 0.2f, integer4 + 1.4f + 0.0625f, (double)renderType, n17, maxY);
                }
                if (Block.fire.canBlockCatchFire(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF - 1)) {
                    instance6.addVertexWithUV((double)integer3, integer4 + 1.4f + 0.0625f, renderType + 0.2f, double4, maxY);
                    instance6.addVertexWithUV((double)integer3, integer4 + 0.0625f, (double)renderType, double4, n5);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 0.0625f, (double)renderType, n17, n5);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 1.4f + 0.0625f, renderType + 0.2f, n17, maxY);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 1.4f + 0.0625f, renderType + 0.2f, n17, maxY);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 0.0625f, (double)renderType, n17, n5);
                    instance6.addVertexWithUV((double)integer3, integer4 + 0.0625f, (double)renderType, double4, n5);
                    instance6.addVertexWithUV((double)integer3, integer4 + 1.4f + 0.0625f, renderType + 0.2f, double4, maxY);
                }
                if (Block.fire.canBlockCatchFire(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF + 1)) {
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 1.4f + 0.0625f, renderType + 1 - 0.2f, n17, maxY);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 0.0625f, (double)(renderType + 1), n17, n5);
                    instance6.addVertexWithUV((double)integer3, integer4 + 0.0625f, (double)(renderType + 1), double4, n5);
                    instance6.addVertexWithUV((double)integer3, integer4 + 1.4f + 0.0625f, renderType + 1 - 0.2f, double4, maxY);
                    instance6.addVertexWithUV((double)integer3, integer4 + 1.4f + 0.0625f, renderType + 1 - 0.2f, double4, maxY);
                    instance6.addVertexWithUV((double)integer3, integer4 + 0.0625f, (double)(renderType + 1), double4, n5);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 0.0625f, (double)(renderType + 1), n17, n5);
                    instance6.addVertexWithUV((double)(integer3 + 1), integer4 + 1.4f + 0.0625f, renderType + 1 - 0.2f, n17, maxY);
                }
                if (Block.fire.canBlockCatchFire(this.blockAccess, integer3, integer4 + 1, renderType)) {
                    final double n20 = integer3 + 0.5f + 0.5f;
                    final double n21 = integer3 + 0.5f - 0.5f;
                    final double n22 = renderType + 0.5f + 0.5f;
                    final double n23 = renderType + 0.5f - 0.5f;
                    n17 = integer2 / 256.0f;
                    double4 = (integer2 + 15.99f) / 256.0f;
                    maxY = n16 / 256.0f;
                    n5 = (n16 + 15.99f) / 256.0f;
                    ++integer4;
                    if ((integer3 + integer4 + renderType & 0x1) == 0x0) {
                        instance6.addVertexWithUV(n21, integer4 - 0.2f, (double)renderType, double4, maxY);
                        instance6.addVertexWithUV(n20, (double)integer4, (double)renderType, double4, n5);
                        instance6.addVertexWithUV(n20, (double)integer4, (double)(renderType + 1), n17, n5);
                        instance6.addVertexWithUV(n21, integer4 - 0.2f, (double)(renderType + 1), n17, maxY);
                        n17 = integer2 / 256.0f;
                        double4 = (integer2 + 15.99f) / 256.0f;
                        maxY = (n16 + 16) / 256.0f;
                        n5 = (n16 + 15.99f + 16.0f) / 256.0f;
                        instance6.addVertexWithUV(n20, integer4 - 0.2f, (double)(renderType + 1), double4, maxY);
                        instance6.addVertexWithUV(n21, (double)integer4, (double)(renderType + 1), double4, n5);
                        instance6.addVertexWithUV(n21, (double)integer4, (double)renderType, n17, n5);
                        instance6.addVertexWithUV(n20, integer4 - 0.2f, (double)renderType, n17, maxY);
                    }
                    else {
                        instance6.addVertexWithUV((double)integer3, integer4 - 0.2f, n22, double4, maxY);
                        instance6.addVertexWithUV((double)integer3, (double)integer4, n23, double4, n5);
                        instance6.addVertexWithUV((double)(integer3 + 1), (double)integer4, n23, n17, n5);
                        instance6.addVertexWithUV((double)(integer3 + 1), integer4 - 0.2f, n22, n17, maxY);
                        n17 = integer2 / 256.0f;
                        double4 = (integer2 + 15.99f) / 256.0f;
                        maxY = (n16 + 16) / 256.0f;
                        n5 = (n16 + 15.99f + 16.0f) / 256.0f;
                        instance6.addVertexWithUV((double)(integer3 + 1), integer4 - 0.2f, n23, double4, maxY);
                        instance6.addVertexWithUV((double)(integer3 + 1), (double)integer4, n22, double4, n5);
                        instance6.addVertexWithUV((double)integer3, (double)integer4, n22, n17, n5);
                        instance6.addVertexWithUV((double)integer3, integer4 - 0.2f, n23, n17, maxY);
                    }
                }
            }
            return true;
        }
        if (renderType == 5) {
            final int n26 = integer2;
            final int n27 = integer3;
            renderType = integer4;
            integer4 = n27;
            integer3 = n26;
            final Tessellator instance7 = Tessellator.instance;
            int n15 = block.getBlockTextureFromSide(0);
            if (this.overrideBlockTexture >= 0) {
                n15 = this.overrideBlockTexture;
            }
            final double n12 = block.getBlockBrightness(this.blockAccess, integer3 & 0xF, integer4 & 0xF, renderType & 0xF);
            instance7.setColorOpaque_F(n12, n12, n12);
            integer2 = ((n15 & 0xF) << 4) + 16;
            int n16 = (n15 & 0xF) << 4;
            final int n28 = n15 & 0xF0;
            if ((integer3 + integer4 + renderType & 0x1) == 0x1) {
                integer2 = (n15 & 0xF) << 4;
                n16 = ((n15 & 0xF) << 4) + 16;
            }
            final double double4 = integer2 / 256.0f;
            final double maxY = (integer2 + 15.99f) / 256.0f;
            final double n5 = n28 / 256.0f;
            final double n29 = (n28 + 15.99f) / 256.0f;
            final double n18 = n16 / 256.0f;
            final double n19 = (n16 + 15.99f) / 256.0f;
            final double n20 = n28 / 256.0f;
            final double n21 = (n28 + 15.99f) / 256.0f;
            if (this.blockAccess.isBlockNormalCube(integer3 - 1, integer4, renderType)) {
                instance7.addVertexWithUV(integer3 + 0.05f, integer4 + 1 + 0.125f, renderType + 1 + 0.125f, double4, n5);
                instance7.addVertexWithUV(integer3 + 0.05f, integer4 - 0.125f, renderType + 1 + 0.125f, double4, n29);
                instance7.addVertexWithUV(integer3 + 0.05f, integer4 - 0.125f, renderType - 0.125f, maxY, n29);
                instance7.addVertexWithUV(integer3 + 0.05f, integer4 + 1 + 0.125f, renderType - 0.125f, maxY, n5);
            }
            if (this.blockAccess.isBlockNormalCube(integer3 + 1, integer4, renderType)) {
                instance7.addVertexWithUV(integer3 + 1 - 0.05f, integer4 - 0.125f, renderType + 1 + 0.125f, maxY, n29);
                instance7.addVertexWithUV(integer3 + 1 - 0.05f, integer4 + 1 + 0.125f, renderType + 1 + 0.125f, maxY, n5);
                instance7.addVertexWithUV(integer3 + 1 - 0.05f, integer4 + 1 + 0.125f, renderType - 0.125f, double4, n5);
                instance7.addVertexWithUV(integer3 + 1 - 0.05f, integer4 - 0.125f, renderType - 0.125f, double4, n29);
            }
            if (this.blockAccess.isBlockNormalCube(integer3 & 0xF, integer4 & 0xF, renderType & 0xF - 1)) {
                instance7.addVertexWithUV(integer3 + 1 + 0.125f, integer4 - 0.125f, renderType + 0.05f, n19, n21);
                instance7.addVertexWithUV(integer3 + 1 + 0.125f, integer4 + 1 + 0.125f, renderType + 0.05f, n19, n20);
                instance7.addVertexWithUV(integer3 - 0.125f, integer4 + 1 + 0.125f, renderType + 0.05f, n18, n20);
                instance7.addVertexWithUV(integer3 - 0.125f, integer4 - 0.125f, renderType + 0.05f, n18, n21);
            }
            if (this.blockAccess.isBlockNormalCube(integer3 & 0xF, integer4 & 0xF, renderType & 0xF + 1)) {
                instance7.addVertexWithUV(integer3 + 1 + 0.125f, integer4 + 1 + 0.125f, renderType + 1 - 0.05f, n18, n20);
                instance7.addVertexWithUV(integer3 + 1 + 0.125f, integer4 - 0.125f, renderType + 1 - 0.05f, n18, n21);
                instance7.addVertexWithUV(integer3 - 0.125f, integer4 - 0.125f, renderType + 1 - 0.05f, n19, n21);
                instance7.addVertexWithUV(integer3 - 0.125f, integer4 + 1 + 0.125f, renderType + 1 - 0.05f, n19, n20);
            }
            return true;
        }
        return false;
    }
    
    private void renderBlockTorch(final Block block, double double2, final double double3, double double4, final double double5, final double double6) {
        final Tessellator instance = Tessellator.instance;
        int n = block.getBlockTextureFromSide(0);
        if (this.overrideBlockTexture >= 0) {
            n = this.overrideBlockTexture;
        }
        final int n2 = (n & 0xF) << 4;
        n &= 0xF0;
        final double n3 = n2 / 256.0f;
        final double n4 = (n2 + 15.99f) / 256.0f;
        final double n5 = n / 256.0f;
        final double n6 = (n + 15.99f) / 256.0f;
        final double n7 = n3 + 0.02734375f;
        final double n8 = n5 + 0.0234375f;
        final double n9 = n3 + 0.03515625f;
        final double n10 = n5 + 0.03125f;
        double2 += 0.5f;
        double4 += 0.5f;
        final double n11 = double2 - 0.5f;
        final double n12 = double2 + 0.5f;
        final double n13 = double4 - 0.5f;
        final double n14 = double4 + 0.5f;
        instance.addVertexWithUV(double2 + double5 * 0.375f - 0.0625f, double3 + 0.625f, double4 + double6 * 0.375f - 0.0625f, n7, n8);
        instance.addVertexWithUV(double2 + double5 * 0.375f - 0.0625f, double3 + 0.625f, double4 + double6 * 0.375f + 0.0625f, n7, n10);
        instance.addVertexWithUV(double2 + double5 * 0.375f + 0.0625f, double3 + 0.625f, double4 + double6 * 0.375f + 0.0625f, n9, n10);
        instance.addVertexWithUV(double2 + double5 * 0.375f + 0.0625f, double3 + 0.625f, double4 + double6 * 0.375f - 0.0625f, n9, n8);
        instance.addVertexWithUV(double2 - 0.0625f, double3 + 1.0f, n13, n3, n5);
        instance.addVertexWithUV(double2 - 0.0625f + double5, double3, n13 + double6, n3, n6);
        instance.addVertexWithUV(double2 - 0.0625f + double5, double3, n14 + double6, n4, n6);
        instance.addVertexWithUV(double2 - 0.0625f, double3 + 1.0f, n14, n4, n5);
        instance.addVertexWithUV(double2 + 0.0625f, double3 + 1.0f, n14, n3, n5);
        instance.addVertexWithUV(double2 + double5 + 0.0625f, double3, n14 + double6, n3, n6);
        instance.addVertexWithUV(double2 + double5 + 0.0625f, double3, n13 + double6, n4, n6);
        instance.addVertexWithUV(double2 + 0.0625f, double3 + 1.0f, n13, n4, n5);
        instance.addVertexWithUV(n11, double3 + 1.0f, double4 + 0.0625f, n3, n5);
        instance.addVertexWithUV(n11 + double5, double3, double4 + 0.0625f + double6, n3, n6);
        instance.addVertexWithUV(n12 + double5, double3, double4 + 0.0625f + double6, n4, n6);
        instance.addVertexWithUV(n12, double3 + 1.0f, double4 + 0.0625f, n4, n5);
        instance.addVertexWithUV(n12, double3 + 1.0f, double4 - 0.0625f, n3, n5);
        instance.addVertexWithUV(n12 + double5, double3, double4 - 0.0625f + double6, n3, n6);
        instance.addVertexWithUV(n11 + double5, double3, double4 - 0.0625f + double6, n4, n6);
        instance.addVertexWithUV(n11, double3 + 1.0f, double4 - 0.0625f, n4, n5);
    }
    
    private void renderBlockPlant(final Block block, int integer, double double3, final double double4, double double5) {
        final Tessellator instance = Tessellator.instance;
        int n = block.getBlockTextureFromSideAndMetadata(0, integer);
        if (this.overrideBlockTexture >= 0) {
            n = this.overrideBlockTexture;
        }
        integer = (n & 0xF) << 4;
        n &= 0xF0;
        final double n2 = integer / 256.0f;
        final double n3 = (integer + 15.99f) / 256.0f;
        final double n4 = n / 256.0f;
        final double n5 = (n + 15.99f) / 256.0f;
        final double n6 = double3 + 0.5f - 0.45f;
        double3 = double3 + 0.5f + 0.45f;
        final double n7 = double5 + 0.5f - 0.45f;
        double5 = double5 + 0.5f + 0.45f;
        instance.addVertexWithUV(n6, double4 + 1.0f, n7, n2, n4);
        instance.addVertexWithUV(n6, double4, n7, n2, n5);
        instance.addVertexWithUV(double3, double4, double5, n3, n5);
        instance.addVertexWithUV(double3, double4 + 1.0f, double5, n3, n4);
        instance.addVertexWithUV(double3, double4 + 1.0f, double5, n2, n4);
        instance.addVertexWithUV(double3, double4, double5, n2, n5);
        instance.addVertexWithUV(n6, double4, n7, n3, n5);
        instance.addVertexWithUV(n6, double4 + 1.0f, n7, n3, n4);
        instance.addVertexWithUV(n6, double4 + 1.0f, double5, n2, n4);
        instance.addVertexWithUV(n6, double4, double5, n2, n5);
        instance.addVertexWithUV(double3, double4, n7, n3, n5);
        instance.addVertexWithUV(double3, double4 + 1.0f, n7, n3, n4);
        instance.addVertexWithUV(double3, double4 + 1.0f, n7, n2, n4);
        instance.addVertexWithUV(double3, double4, n7, n2, n5);
        instance.addVertexWithUV(n6, double4, double5, n3, n5);
        instance.addVertexWithUV(n6, double4 + 1.0f, double5, n3, n4);
    }
    
    private void renderBlockCrops(final Block block, int integer, final double double3, final double double4, final double double5) {
        final Tessellator instance = Tessellator.instance;
        int n = block.getBlockTextureFromSideAndMetadata(0, integer);
        if (this.overrideBlockTexture >= 0) {
            n = this.overrideBlockTexture;
        }
        integer = (n & 0xF) << 4;
        n &= 0xF0;
        final double n2 = integer / 256.0f;
        final double n3 = (integer + 15.99f) / 256.0f;
        final double n4 = n / 256.0f;
        final double n5 = (n + 15.99f) / 256.0f;
        double n6 = double3 + 0.5f - 0.25f;
        double n7 = double3 + 0.5f + 0.25f;
        double n8 = double5 + 0.5f - 0.5f;
        double n9 = double5 + 0.5f + 0.5f;
        instance.addVertexWithUV(n6, double4 + 1.0f, n8, n2, n4);
        instance.addVertexWithUV(n6, double4, n8, n2, n5);
        instance.addVertexWithUV(n6, double4, n9, n3, n5);
        instance.addVertexWithUV(n6, double4 + 1.0f, n9, n3, n4);
        instance.addVertexWithUV(n6, double4 + 1.0f, n9, n2, n4);
        instance.addVertexWithUV(n6, double4, n9, n2, n5);
        instance.addVertexWithUV(n6, double4, n8, n3, n5);
        instance.addVertexWithUV(n6, double4 + 1.0f, n8, n3, n4);
        instance.addVertexWithUV(n7, double4 + 1.0f, n9, n2, n4);
        instance.addVertexWithUV(n7, double4, n9, n2, n5);
        instance.addVertexWithUV(n7, double4, n8, n3, n5);
        instance.addVertexWithUV(n7, double4 + 1.0f, n8, n3, n4);
        instance.addVertexWithUV(n7, double4 + 1.0f, n8, n2, n4);
        instance.addVertexWithUV(n7, double4, n8, n2, n5);
        instance.addVertexWithUV(n7, double4, n9, n3, n5);
        instance.addVertexWithUV(n7, double4 + 1.0f, n9, n3, n4);
        n6 = double3 + 0.5f - 0.5f;
        n7 = double3 + 0.5f + 0.5f;
        n8 = double5 + 0.5f - 0.25f;
        n9 = double5 + 0.5f + 0.25f;
        instance.addVertexWithUV(n6, double4 + 1.0f, n8, n2, n4);
        instance.addVertexWithUV(n6, double4, n8, n2, n5);
        instance.addVertexWithUV(n7, double4, n8, n3, n5);
        instance.addVertexWithUV(n7, double4 + 1.0f, n8, n3, n4);
        instance.addVertexWithUV(n7, double4 + 1.0f, n8, n2, n4);
        instance.addVertexWithUV(n7, double4, n8, n2, n5);
        instance.addVertexWithUV(n6, double4, n8, n3, n5);
        instance.addVertexWithUV(n6, double4 + 1.0f, n8, n3, n4);
        instance.addVertexWithUV(n7, double4 + 1.0f, n9, n2, n4);
        instance.addVertexWithUV(n7, double4, n9, n2, n5);
        instance.addVertexWithUV(n6, double4, n9, n3, n5);
        instance.addVertexWithUV(n6, double4 + 1.0f, n9, n3, n4);
        instance.addVertexWithUV(n6, double4 + 1.0f, n9, n2, n4);
        instance.addVertexWithUV(n6, double4, n9, n2, n5);
        instance.addVertexWithUV(n7, double4, n9, n3, n5);
        instance.addVertexWithUV(n7, double4 + 1.0f, n9, n3, n4);
    }
    
    private double materialNotWater(final int integer1, final int integer2, final int integer3) {
        if (this.blockAccess.getBlockMaterial(integer1, integer2, integer3) != Material.water) {
            return 1.0f;
        }
        return this.blockAccess.getBlockMetadata(integer1, integer2, integer3) / 9.0f;
    }
    
    private void renderBlockBottom(final Block block, double double2, double double3, final double double4, int integer) {
        final Tessellator instance = Tessellator.instance;
        if (this.overrideBlockTexture >= 0) {
            integer = this.overrideBlockTexture;
        }
        final int n = (integer & 0xF) << 4;
        integer &= 0xF0;
        final double n2 = n / 256.0f;
        final double n3 = (n + 15.99f) / 256.0f;
        final double n4 = integer / 256.0f;
        final double n5 = (integer + 15.99f) / 256.0f;
        final double n6 = double2 + block.minX;
        double2 += block.maxX;
        double3 += block.minY;
        final double n7 = double4 + block.minZ;
        final double n8 = double4 + block.maxZ;
        instance.addVertexWithUV(n6, double3, n8, n2, n5);
        instance.addVertexWithUV(n6, double3, n7, n2, n4);
        instance.addVertexWithUV(double2, double3, n7, n3, n4);
        instance.addVertexWithUV(double2, double3, n8, n3, n5);
    }
    
    private void renderBlockTop(final Block block, double double2, double double3, final double double4, int integer) {
        final Tessellator instance = Tessellator.instance;
        if (this.overrideBlockTexture >= 0) {
            integer = this.overrideBlockTexture;
        }
        final int n = (integer & 0xF) << 4;
        integer &= 0xF0;
        final double n2 = n / 256.0f;
        final double n3 = (n + 15.99f) / 256.0f;
        final double n4 = integer / 256.0f;
        final double n5 = (integer + 15.99f) / 256.0f;
        final double n6 = double2 + block.minX;
        double2 += block.maxX;
        double3 += block.maxY;
        final double n7 = double4 + block.minZ;
        final double n8 = double4 + block.maxZ;
        instance.addVertexWithUV(double2, double3, n8, n3, n5);
        instance.addVertexWithUV(double2, double3, n7, n3, n4);
        instance.addVertexWithUV(n6, double3, n7, n2, n4);
        instance.addVertexWithUV(n6, double3, n8, n2, n5);
    }
    
    private void renderBlockNorth(final Block block, final int integer2, final int integer3, final int integer4, int integer5) {
        final Tessellator instance = Tessellator.instance;
        if (this.overrideBlockTexture >= 0) {
            integer5 = this.overrideBlockTexture;
        }
        final int n = (integer5 & 0xF) << 4;
        integer5 &= 0xF0;
        final double n2 = n / 256.0f;
        final double n3 = (n + 15.99f) / 256.0f;
        double n4;
        double n5;
        if (block.minY < 0.0f || block.maxY > 1.0f) {
            n4 = integer5 / 256.0f;
            n5 = (integer5 + 15.99f) / 256.0f;
        }
        else {
            n4 = (integer5 + block.minY * 15.99f) / 256.0f;
            n5 = (integer5 + block.maxY * 15.99f) / 256.0f;
        }
        final double n6 = integer2 + block.minX;
        final double n7 = integer2 + block.maxX;
        final double n8 = integer3 + block.minY;
        final double n9 = integer3 + block.maxY;
        final double n10 = integer4 + block.minZ;
        instance.addVertexWithUV(n6, n9, n10, n3, n4);
        instance.addVertexWithUV(n7, n9, n10, n2, n4);
        instance.addVertexWithUV(n7, n8, n10, n2, n5);
        instance.addVertexWithUV(n6, n8, n10, n3, n5);
    }
    
    private void renderBlockSouth(final Block block, final int integer2, final int integer3, final int integer4, int integer5) {
        final Tessellator instance = Tessellator.instance;
        if (this.overrideBlockTexture >= 0) {
            integer5 = this.overrideBlockTexture;
        }
        final int n = (integer5 & 0xF) << 4;
        integer5 &= 0xF0;
        final double n2 = n / 256.0f;
        final double n3 = (n + 15.99f) / 256.0f;
        double n4;
        double n5;
        if (block.minY < 0.0f || block.maxY > 1.0f) {
            n4 = integer5 / 256.0f;
            n5 = (integer5 + 15.99f) / 256.0f;
        }
        else {
            n4 = (integer5 + block.minY * 15.99f) / 256.0f;
            n5 = (integer5 + block.maxY * 15.99f) / 256.0f;
        }
        final double n6 = integer2 + block.minX;
        final double n7 = integer2 + block.maxX;
        final double n8 = integer3 + block.minY;
        final double n9 = integer3 + block.maxY;
        final double n10 = integer4 + block.maxZ;
        instance.addVertexWithUV(n6, n9, n10, n2, n4);
        instance.addVertexWithUV(n6, n8, n10, n2, n5);
        instance.addVertexWithUV(n7, n8, n10, n3, n5);
        instance.addVertexWithUV(n7, n9, n10, n3, n4);
    }
    
    private void renderBlockWest(final Block block, final int integer2, final int integer3, final int integer4, int integer5) {
        final Tessellator instance = Tessellator.instance;
        if (this.overrideBlockTexture >= 0) {
            integer5 = this.overrideBlockTexture;
        }
        final int n = (integer5 & 0xF) << 4;
        integer5 &= 0xF0;
        final double n2 = n / 256.0f;
        final double n3 = (n + 15.99f) / 256.0f;
        double n4;
        double n5;
        if (block.minY < 0.0f || block.maxY > 1.0f) {
            n4 = integer5 / 256.0f;
            n5 = (integer5 + 15.99f) / 256.0f;
        }
        else {
            n4 = (integer5 + block.minY * 15.99f) / 256.0f;
            n5 = (integer5 + block.maxY * 15.99f) / 256.0f;
        }
        final double n6 = integer2 + block.minX;
        final double n7 = integer3 + block.minY;
        final double n8 = integer3 + block.maxY;
        final double n9 = integer4 + block.minZ;
        final double n10 = integer4 + block.maxZ;
        instance.addVertexWithUV(n6, n8, n10, n3, n4);
        instance.addVertexWithUV(n6, n8, n9, n2, n4);
        instance.addVertexWithUV(n6, n7, n9, n2, n5);
        instance.addVertexWithUV(n6, n7, n10, n3, n5);
    }
    
    private void renderBlockEast(final Block block, final int integer2, final int integer3, final int integer4, int integer5) {
        final Tessellator instance = Tessellator.instance;
        if (this.overrideBlockTexture >= 0) {
            integer5 = this.overrideBlockTexture;
        }
        final int n = (integer5 & 0xF) << 4;
        integer5 &= 0xF0;
        final double n2 = n / 256.0f;
        final double n3 = (n + 15.99f) / 256.0f;
        double n4;
        double n5;
        if (block.minY < 0.0f || block.maxY > 1.0f) {
            n4 = integer5 / 256.0f;
            n5 = (integer5 + 15.99f) / 256.0f;
        }
        else {
            n4 = (integer5 + block.minY * 15.99f) / 256.0f;
            n5 = (integer5 + block.maxY * 15.99f) / 256.0f;
        }
        final double n6 = integer2 + block.maxX;
        final double n7 = integer3 + block.minY;
        final double n8 = integer3 + block.maxY;
        final double n9 = integer4 + block.minZ;
        final double n10 = integer4 + block.maxZ;
        instance.addVertexWithUV(n6, n7, n10, n2, n5);
        instance.addVertexWithUV(n6, n7, n9, n3, n5);
        instance.addVertexWithUV(n6, n8, n9, n3, n4);
        instance.addVertexWithUV(n6, n8, n10, n2, n4);
    }
    
    public final void renderBlockOnInventory(final Block block) {
        final Tessellator instance = Tessellator.instance;
        final int renderType;
        if ((renderType = block.getRenderType()) == 0) {
            GL11.glTranslated(-0.5f, -0.5f, -0.5f);
            instance.startDrawingQuads();
            Tessellator.setNormal(0.0f, -1.0f, 0.0f);
            this.renderBlockBottom(block, 0.0f, 0.0f, 0.0f, block.getBlockTextureFromSide(0));
            instance.draw();
            instance.startDrawingQuads();
            Tessellator.setNormal(0.0f, 1.0f, 0.0f);
            this.renderBlockTop(block, 0.0f, 0.0f, 0.0f, block.getBlockTextureFromSide(1));
            instance.draw();
            instance.startDrawingQuads();
            Tessellator.setNormal(0.0f, 0.0f, -1.0f);
            this.renderBlockNorth(block, 0, 0, 0, block.getBlockTextureFromSide(2));
            instance.draw();
            instance.startDrawingQuads();
            Tessellator.setNormal(0.0f, 0.0f, 1.0f);
            this.renderBlockSouth(block, 0, 0, 0, block.getBlockTextureFromSide(3));
            instance.draw();
            instance.startDrawingQuads();
            Tessellator.setNormal(-1.0f, 0.0f, 0.0f);
            this.renderBlockWest(block, 0, 0, 0, block.getBlockTextureFromSide(4));
            instance.draw();
            instance.startDrawingQuads();
            Tessellator.setNormal(1.0f, 0.0f, 0.0f);
            this.renderBlockEast(block, 0, 0, 0, block.getBlockTextureFromSide(5));
            instance.draw();
            GL11.glTranslated(0.5f, 0.5f, 0.5f);
            return;
        }
        if (renderType == 1) {
            instance.startDrawingQuads();
            Tessellator.setNormal(0.0f, -1.0f, 0.0f);
            this.renderBlockPlant(block, -1, -0.5f, -0.5f, -0.5f);
            instance.draw();
            return;
        }
        if (renderType == 6) {
            instance.startDrawingQuads();
            Tessellator.setNormal(0.0f, -1.0f, 0.0f);
            this.renderBlockCrops(block, -1, -0.5f, -0.5f, -0.5f);
            instance.draw();
            return;
        }
        if (renderType == 2) {
            instance.startDrawingQuads();
            Tessellator.setNormal(0.0f, -1.0f, 0.0f);
            this.renderBlockTorch(block, -0.5f, -0.5f, -0.5f, 0.0f, 0.0f);
            instance.draw();
        }
    }
}
