package net.minecraft.client.renderer.block;

import net.minecraft.game.block.Block;

public final class TextureWaterFlowFX extends TextureFX {
    private double[] red;
    private double[] green;
    private double[] blue;
    private double[] alpha;
    private int tickCounter;
    
    public TextureWaterFlowFX() {
        super(Block.waterMoving.blockIndexInTexture + 32);
        this.red = new double[256];
        this.green = new double[256];
        this.blue = new double[256];
        this.alpha = new double[256];
        this.tickCounter = 0;
    }
    
    @Override
    public final void onTick() {
        ++this.tickCounter;
        for (int i = 0; i < 16; ++i) {
            for (int j = 0; j < 16; ++j) {
                double n = 0.0f;
                for (int k = j - 2; k <= j; ++k) {
                    final int n2 = i & 0xF;
                    final int n3 = k & 0xF;
                    n += this.red[n2 + (n3 << 4)];
                }
                this.green[i + (j << 4)] = n / 3.2f + this.blue[i + (j << 4)] * 0.8f;
            }
        }
        for (int i = 0; i < 16; ++i) {
            for (int j = 0; j < 16; ++j) {
                final double[] blue = this.blue;
                final int n4 = i + (j << 4);
                blue[n4] += this.alpha[i + (j << 4)] * 0.05f;
                if (this.blue[i + (j << 4)] < 0.0f) {
                    this.blue[i + (j << 4)] = 0.0f;
                }
                final double[] alpha = this.alpha;
                final int n5 = i + (j << 4);
                alpha[n5] -= 0.3f;
                if (Math.random() < 0.2) {
                    this.alpha[i + (j << 4)] = 0.5f;
                }
            }
        }
        final double[] green = this.green;
        this.green = this.red;
        this.red = green;
        for (int j = 0; j < 256; ++j) {
            double n;
            if ((n = this.red[j]) > 1.0f) {
                n = 1.0f;
            }
            if (n < 0.0f) {
                n = 0.0f;
            }
            final double n6 = n * n;
            int n2 = (int)(32.0f + n6 * 32.0f);
            int n3 = (int)(50.0f + n6 * 64.0f);
            int i = 255;
            final int n7 = (int)(146.0f + n6 * 50.0f);
            if (this.anaglyphEnabled) {
                i = (n2 * 30 + n3 * 59 + 2805) / 100;
                final int k = (n2 * 30 + n3 * 70) / 100;
                final int n8 = (n2 * 30 + 17850) / 100;
                n2 = i;
                n3 = k;
                i = n8;
            }
            this.imageData[j << 2] = (byte)n2;
            this.imageData[(j << 2) + 1] = (byte)n3;
            this.imageData[(j << 2) + 2] = (byte)i;
            this.imageData[(j << 2) + 3] = (byte)n7;
        }
    }
}
