package net.minecraft.client.renderer.entity;

import net.minecraft.game.entity.Entity;
import net.minecraft.game.item.Item;
import net.minecraft.game.item.ItemStack;
import net.minecraft.game.item.ItemArmor;
import net.minecraft.game.entity.EntityLiving;
import net.minecraft.game.entity.player.EntityPlayer;
import net.minecraft.client.model.ModelBase;
import net.minecraft.client.model.ModelBiped;
import net.minecraft.client.model.ModelRenderer;

public final class RenderPlayer extends RenderLiving {
    private ModelBiped modelBipedMain;
    private ModelBiped modelArmorChestplate;
    private ModelBiped modelArmor;
    private static final String[] armorFilenamePrefix;
    
    public RenderPlayer() {
        super(new ModelBiped(0.0f), 0.5f);
        this.modelBipedMain = (ModelBiped)this.mainModel;
        this.modelArmorChestplate = new ModelBiped(1.0f);
        this.modelArmor = new ModelBiped(0.5f);
    }
    
    private void renderPlayer(final EntityPlayer player, final double double2, final double double3, final double double4, final double double5, final double double6) {
        super.doRender(player, double2, double3 - player.yOffset, double4, double5, double6);
    }
    
    public final void drawFirstPersonHand() {
        this.modelBipedMain.bipedRightArm.render(1.0f);
    }
    
    
    public final boolean shouldRenderPass(EntityLiving entity, int i) {
        boolean z = false;
        ItemStack itemStack = ((EntityPlayer) entity).inventory.armorInventory[3 - i];
        if (itemStack != null) {
            Item a = itemStack.getItem();
            if (a instanceof ItemArmor) {
                loadTexture("/armor/" + armorFilenamePrefix[((ItemArmor) a).renderIndex] + "_" + (i == 2 ? 2 : 1) + ".png");
                ModelBiped modelBiped = i == 2 ? this.modelArmor : this.modelArmorChestplate;
                modelBiped.bipedHead.showModel = i == 0;
                modelBiped.bipedHeadwear.showModel = i == 0;
                modelBiped.bipedBody.showModel = i == 1 || i == 2;
                modelBiped.bipedLeftArm.showModel = i == 1;
                modelBiped.bipedRightArm.showModel = i == 1;
                modelBiped.bipedLeftLeg.showModel = i == 2 || i == 3;
                ModelRenderer cVar = modelBiped.bipedRightLeg;
                if (i == 2 || i == 3) {
                    z = true;
                }
                cVar.showModel = z;
                setRenderPassModel((ModelBase) modelBiped);
                return true;
            }
        }
        return false;
    }
    
    public void doRender(Entity entity, double d, double d1, double d2, double f, double f1)
    {
    	this.renderPlayer((EntityPlayer)entity, d, d1, d2, f, f1);
    }
    
    static {
        armorFilenamePrefix = new String[] { "cloth", "chain", "iron", "diamond", "gold" };
    }
}
