package net.minecraft.game.block;

import net.minecraft.game.level.World;
import java.util.Random;
import net.minecraft.client.physics.AxisAlignedBB;

public final class BlockFire extends Block {
    private int[] chanceToEncourageFire;
    private int[] abilityToCatchFire;
    
    protected BlockFire(int blockID, final int textureSlot) {
        super(51, 31, Material.fire);
        this.chanceToEncourageFire = new int[256];
        this.abilityToCatchFire = new int[256];
        this.setBurnRate(Block.planks.blockID, 5, 20);
        this.setBurnRate(Block.wood.blockID, 5, 5);
        this.setBurnRate(Block.leaves.blockID, 30, 60);
        this.setBurnRate(Block.bookShelf.blockID, 30, 20);
        this.setBurnRate(Block.tnt.blockID, 15, 100);
        for (blockID = 0; blockID < 16; ++blockID) {
            this.setBurnRate(Block.woolRed.blockID + blockID, 30, 60);
        }
        this.setTickOnLoad(true);
    }
    
    private void setBurnRate(final int integer1, final int integer2, final int integer3) {
        this.chanceToEncourageFire[integer1] = integer2;
        this.abilityToCatchFire[integer1] = integer3;
    }
    
    @Override
    public final AxisAlignedBB getCollisionBoundingBoxFromPool(final int xCoord, final int yCoord, final int zCoord) {
        return null;
    }
    
    @Override
    public final boolean isOpaqueCube() {
        return false;
    }
    
    @Override
    public final boolean renderAsNormalBlock() {
        return false;
    }
    
    @Override
    public final int getRenderType() {
        return 3;
    }
    
    @Override
    public final int quantityDropped(final Random random) {
        return 0;
    }
    
    @Override
    public final int tickRate() {
        return 20;
    }
    
    @Override
    public final void updateTick(final World world, final int xCoord, final int yCoord, final int zCoord, final Random random) {
        int i;
        if ((i = world.getBlockMetadata(xCoord, yCoord, zCoord)) < 15) {
            world.setBlockMetadataWithNotify(xCoord, yCoord, zCoord, i + 1);
            world.scheduleBlockUpdate(xCoord, yCoord, zCoord, this.blockID);
        }
        if (!this.canNeighborCatchFire(world, xCoord, yCoord, zCoord)) {
            if (!world.isBlockNormalCube(xCoord, yCoord - 1, zCoord) || i > 3) {
                world.setBlockWithNotify(xCoord, yCoord, zCoord, 0);
            }
            return;
        }
        if (!this.canBlockCatchFire(world, xCoord, yCoord - 1, zCoord) && i == 15 && random.nextInt(4) == 0) {
            world.setBlockWithNotify(xCoord, yCoord, zCoord, 0);
            return;
        }
        if (i % 5 == 0 && i > 5) {
            this.tryToCatchBlockOnFire(world, xCoord + 1, yCoord, zCoord, 300, random);
            this.tryToCatchBlockOnFire(world, xCoord - 1, yCoord, zCoord, 300, random);
            this.tryToCatchBlockOnFire(world, xCoord, yCoord - 1, zCoord, 100, random);
            this.tryToCatchBlockOnFire(world, xCoord, yCoord + 1, zCoord, 200, random);
            this.tryToCatchBlockOnFire(world, xCoord, yCoord, zCoord - 1, 300, random);
            this.tryToCatchBlockOnFire(world, xCoord, yCoord, zCoord + 1, 300, random);
            for (i = xCoord - 1; i <= xCoord + 1; ++i) {
                for (int j = zCoord - 1; j <= zCoord + 1; ++j) {
                    for (int k = yCoord - 1; k <= yCoord + 4; ++k) {
                        if (i != xCoord || k != yCoord || j != zCoord) {
                            int n = 100;
                            if (k > yCoord + 1) {
                                n = 100 + (k - (yCoord + 1)) * 100;
                            }
                            final int n2 = i;
                            final int n3 = k;
                            final int integer4 = j;
                            final int integer5 = n3;
                            final int integer6 = n2;
                            int n4;
                            int chanceToEncourageFire;
                            if (world.getBlockId(integer6, integer5, integer4) != 0) {
                                chanceToEncourageFire = (n4 = 0);
                            }
                            else {
                                int integer7 = this.getChanceToEncourageFire(world, integer6 + 1, integer5, integer4, 0);
                                integer7 = this.getChanceToEncourageFire(world, integer6 - 1, integer5, integer4, integer7);
                                integer7 = this.getChanceToEncourageFire(world, integer6, integer5 - 1, integer4, integer7);
                                integer7 = this.getChanceToEncourageFire(world, integer6, integer5 + 1, integer4, integer7);
                                integer7 = this.getChanceToEncourageFire(world, integer6, integer5, integer4 - 1, integer7);
                                n4 = (integer7 = (chanceToEncourageFire = this.getChanceToEncourageFire(world, integer6, integer5, integer4 + 1, integer7)));
                            }
                            final int n5 = n4;
                            if (chanceToEncourageFire > 0 && random.nextInt(n) <= n5) {
                                world.setBlockWithNotify(i, k, j, this.blockID);
                            }
                        }
                    }
                }
            }
        }
    }
    
    private void tryToCatchBlockOnFire(final World world, final int integer2, final int integer3, final int integer4, int integer5, final Random random) {
        if (random.nextInt(integer5) < this.abilityToCatchFire[world.getBlockId(integer2, integer3, integer4)]) {
            integer5 = ((world.getBlockId(integer2, integer3, integer4) == Block.tnt.blockID) ? 1 : 0);
            if (random.nextInt(2) == 0) {
                world.setBlockWithNotify(integer2, integer3, integer4, this.blockID);
            }
            else {
                world.setBlockWithNotify(integer2, integer3, integer4, 0);
            }
            if (integer5 != 0) {
                Block.tnt.onBlockDestroyedByPlayer(world, integer2, integer3, integer4, 0);
            }
        }
    }
    
    private boolean canNeighborCatchFire(final World world, final int integer2, final int integer3, final int integer4) {
        return this.canBlockCatchFire(world, integer2 + 1, integer3, integer4) || this.canBlockCatchFire(world, integer2 - 1, integer3, integer4) || this.canBlockCatchFire(world, integer2, integer3 - 1, integer4) || this.canBlockCatchFire(world, integer2, integer3 + 1, integer4) || this.canBlockCatchFire(world, integer2, integer3, integer4 - 1) || this.canBlockCatchFire(world, integer2, integer3, integer4 + 1);
    }
    
    @Override
    public final boolean isCollidable() {
        return false;
    }
    
    public final boolean canBlockCatchFire(final World world, final int integer2, final int integer3, final int integer4) {
        return this.chanceToEncourageFire[world.getBlockId(integer2, integer3, integer4)] > 0;
    }
    
    private int getChanceToEncourageFire(final World world, final int integer2, final int integer3, final int integer4, final int integer5) {
        final int n;
        if ((n = this.chanceToEncourageFire[world.getBlockId(integer2, integer3, integer4)]) > integer5) {
            return n;
        }
        return integer5;
    }
    
    @Override
    public final boolean canPlaceBlockAt(final World world, final int xCoord, final int yCoord, final int zCoord) {
        return world.isBlockNormalCube(xCoord, yCoord - 1, zCoord) || this.canNeighborCatchFire(world, xCoord, yCoord, zCoord);
    }
    
    @Override
    public final void onNeighborBlockChange(final World world, final int xCoord, final int yCoord, final int zCoord, final int blockID) {
        if (!world.isBlockNormalCube(xCoord, yCoord - 1, zCoord) && !this.canNeighborCatchFire(world, xCoord, yCoord, zCoord)) {
            world.setBlockWithNotify(xCoord, yCoord, zCoord, 0);
        }
    }
    
    @Override
    public final void onBlockAdded(final World world, final int xCoord, final int yCoord, final int zCoord) {
        if (!world.isBlockNormalCube(xCoord, yCoord - 1, zCoord) && !this.canNeighborCatchFire(world, xCoord, yCoord, zCoord)) {
            world.setBlockWithNotify(xCoord, yCoord, zCoord, 0);
            return;
        }
        world.scheduleBlockUpdate(xCoord, yCoord, zCoord, this.blockID);
    }
    
    public final boolean getChanceOfNeighborsEncouragingFire(final int integer) {
        return this.chanceToEncourageFire[integer] > 0;
    }
    
    public final void fireSpread(final World world, final int xCoord, final int yCoord, final int zCoord) {
        boolean b = false;
        if (!(b = fireCheck(world, xCoord, yCoord + 1, zCoord))) {
            b = fireCheck(world, xCoord - 1, yCoord, zCoord);
        }
        if (!b) {
            b = fireCheck(world, xCoord + 1, yCoord, zCoord);
        }
        if (!b) {
            b = fireCheck(world, xCoord, yCoord, zCoord - 1);
        }
        if (!b) {
            b = fireCheck(world, xCoord, yCoord, zCoord + 1);
        }
        if (!b) {
            b = fireCheck(world, xCoord, yCoord - 1, zCoord);
        }
        if (!b) {
            world.setBlockWithNotify(xCoord, yCoord, zCoord, Block.fire.blockID);
        }
    }
    
    @Override
    public final void randomDisplayTick(final World world, final int xCoord, final int yCoord, final int zCoord, final Random random) {
        if (random.nextInt(24) == 0) {
            world.playSoundAtPlayer(xCoord + 0.5f, yCoord + 0.5f, zCoord + 0.5f, "fire.fire", 1.0f + random.nextDouble(), random.nextDouble() * 0.7f + 0.3f);
        }
        if (world.isBlockNormalCube(xCoord, yCoord - 1, zCoord) || Block.fire.canBlockCatchFire(world, xCoord, yCoord - 1, zCoord)) {
            for (int i = 0; i < 3; ++i) {
                final double n = xCoord + random.nextDouble();
                final double n2 = yCoord + random.nextDouble() * 0.5f + 0.5f;
                final double n3 = zCoord + random.nextDouble();
                world.spawnParticle("largesmoke", n, n2, n3, 0.0f, 0.0f, 0.0f);
            }
            return;
        }
        if (Block.fire.canBlockCatchFire(world, xCoord - 1, yCoord, zCoord)) {
            for (int i = 0; i < 2; ++i) {
                final double n = xCoord + random.nextDouble() * 0.1f;
                final double n2 = yCoord + random.nextDouble();
                final double n3 = zCoord + random.nextDouble();
                world.spawnParticle("largesmoke", n, n2, n3, 0.0f, 0.0f, 0.0f);
            }
        }
        if (Block.fire.canBlockCatchFire(world, xCoord + 1, yCoord, zCoord)) {
            for (int i = 0; i < 2; ++i) {
                final double n = xCoord + 1 - random.nextDouble() * 0.1f;
                final double n2 = yCoord + random.nextDouble();
                final double n3 = zCoord + random.nextDouble();
                world.spawnParticle("largesmoke", n, n2, n3, 0.0f, 0.0f, 0.0f);
            }
        }
        if (Block.fire.canBlockCatchFire(world, xCoord, yCoord, zCoord - 1)) {
            for (int i = 0; i < 2; ++i) {
                final double n = xCoord + random.nextDouble();
                final double n2 = yCoord + random.nextDouble();
                final double n3 = zCoord + random.nextDouble() * 0.1f;
                world.spawnParticle("largesmoke", n, n2, n3, 0.0f, 0.0f, 0.0f);
            }
        }
        if (Block.fire.canBlockCatchFire(world, xCoord, yCoord, zCoord + 1)) {
            for (int i = 0; i < 2; ++i) {
                final double n = xCoord + random.nextDouble();
                final double n2 = yCoord + random.nextDouble();
                final double n3 = zCoord + 1 - random.nextDouble() * 0.1f;
                world.spawnParticle("largesmoke", n, n2, n3, 0.0f, 0.0f, 0.0f);
            }
        }
        if (Block.fire.canBlockCatchFire(world, xCoord, yCoord + 1, zCoord)) {
            for (int i = 0; i < 2; ++i) {
                final double n = xCoord + random.nextDouble();
                final double n2 = yCoord + 1 - random.nextDouble() * 0.1f;
                final double n3 = zCoord + random.nextDouble();
                world.spawnParticle("largesmoke", n, n2, n3, 0.0f, 0.0f, 0.0f);
            }
        }
    }
    
    private static boolean fireCheck(final World world, final int integer2, final int integer3, final int integer4) {
        final int blockId;
        if ((blockId = world.getBlockId(integer2, integer3, integer4)) == Block.fire.blockID) {
            return true;
        }
        if (blockId == 0) {
            world.setBlockWithNotify(integer2, integer3, integer4, Block.fire.blockID);
            return true;
        }
        return false;
    }
}
