package net.minecraft.game.entity.monster;

import net.minecraft.game.item.Item;
import com.nbt.NBTTagCompound;
import net.minecraft.game.MathHelper;
import net.minecraft.game.entity.EntityLiving;
import net.minecraft.game.entity.other.EntityArrow;
import net.minecraft.game.entity.Entity;
import net.minecraft.game.level.World;

public class EntitySkeleton extends EntityMonster {
    public EntitySkeleton(final World world) {
        super(world);
        this.texture = "/mob/skeleton.png";
    }
    
    @Override
    public final void onLivingUpdate() {
        final double entityBrightness;
        if (this.worldObj.skylightSubtracted > 7 && (entityBrightness = this.getEntityBrightness(1.0f)) > 0.5f && this.worldObj.canBlockSeeTheSky((int)this.posX, (int)this.posY, (int)this.posZ) && this.rand.nextDouble() * 30.0f < (entityBrightness - 0.4f) * 2.0f) {
            this.fire = 300;
        }
        super.onLivingUpdate();
    }
    
    @Override
    protected final void attackEntity(final Entity entity, double double2) {
        if (double2 < 10.0f) {
            double2 = entity.posX - this.posX;
            final double double3 = entity.posZ - this.posZ;
            if (this.attackTime == 0) {
                final EntityArrow entity2;
                final EntityArrow entityArrow = entity2 = new EntityArrow(this.worldObj, this);
                entityArrow.posY += 1.4f;
                final double n = entity.posY - 0.2f - entity2.posY;
                final double n2 = MathHelper.sqrt_double(double2 * double2 + double3 * double3) * 0.2f;
                this.worldObj.playSoundAtEntity((Entity)this, "random.bow", 1.0f, 1.0f / (this.rand.nextDouble() * 0.4f + 0.8f));
                this.worldObj.entityJoinedWorld(entity2);
                entity2.setArrowHeading(double2, n + n2, double3, 0.6f, 12.0f);
                this.attackTime = 30;
            }
            this.rotationYaw = (double)(Math.atan2((double)double3, (double)double2) * 180.0 / 3.1415927410125732) - 90.0f;
            this.hasAttacked = true;
        }
    }
    
    @Override
    protected final void writeEntityToNBT(final NBTTagCompound nbtTagCompound) {
        super.writeEntityToNBT(nbtTagCompound);
    }
    
    @Override
    protected final void readEntityFromNBT(final NBTTagCompound nbtTagCompound) {
        super.readEntityFromNBT(nbtTagCompound);
    }
    
    @Override
    protected final String getEntityString() {
        return "Skeleton";
    }
    
    @Override
    protected final int scoreValue() {
        return Item.arrow.shiftedIndex;
    }
}
