package net.minecraft.game.entity.player;

import net.minecraft.game.block.tileentity.TileEntityFurnace;
import net.minecraft.game.item.ItemArmor;
import net.minecraft.game.entity.other.EntityArrow;
import net.minecraft.game.entity.monster.EntityMonster;
import net.minecraft.client.inventory.IInventory;
import com.nbt.NBTTagCompound;
import net.minecraft.game.item.Item;
import net.minecraft.game.block.Material;
import net.minecraft.game.block.Block;
import net.minecraft.game.entity.other.EntityItem;
import java.util.List;
import net.minecraft.game.item.ItemStack;
import net.minecraft.game.MathHelper;
import net.minecraft.game.entity.Entity;
import net.minecraft.game.level.World;
import net.minecraft.game.entity.EntityLiving;

public class EntityPlayer extends EntityLiving {
    public InventoryPlayer inventory;
    public byte unusedByte;
    public int getScore;
    public double prevCameraYaw;
    public double cameraYaw;
    private int swingProgressInt;
    
    public EntityPlayer(final World world) {
        super(world);
        this.inventory = new InventoryPlayer(this);
        this.unusedByte = 0;
        this.getScore = 0;
        this.swingProgressInt = 0;
        if (world != null) {
            world.releaseEntitySkin(world.player = this);
        }
        this.setPositionAndRotation((double)world.xSpawn, (double)world.ySpawn, (double)world.zSpawn, 0.0f, 0.0f);
        this.yOffset = 1.62f;
        this.health = 20;
        this.fireResistance = 20;
        this.texture = "/char.png";
    }
    
    public final void preparePlayerToSpawn() {
        this.yOffset = 1.62f;
        this.setSize(0.6f, 1.8f);
        super.preparePlayerToSpawn();
        if (this.worldObj != null) {
            this.worldObj.player = this;
        }
        this.health = 20;
        this.deathTime = 0;
    }
    
    @Override
    public void onLivingUpdate() {
        this.worldObj.playSoundEffect(this.posX, this.posY, this.posZ, "calm", 0.0f);
        if (this.worldObj.difficultySetting == 0 && this.health < 20 && this.ticksExisted % 20 << 2 == 0) {
            this.heal(1);
        }
        final InventoryPlayer inventory = this.inventory;
        for (int i = 0; i < inventory.mainInventory.length; ++i) {
            if (inventory.mainInventory[i] != null && inventory.mainInventory[i].animationsToGo > 0) {
                final ItemStack itemStack = inventory.mainInventory[i];
                --itemStack.animationsToGo;
            }
        }
        this.prevCameraYaw = this.cameraYaw;
        super.onLivingUpdate();
        double sqrt_double = MathHelper.sqrt_double(this.motionX * this.motionX + this.motionZ * this.motionZ);
        double n = (double)Math.atan((double)(-this.motionY * 0.2f)) * 15.0f;
        if (sqrt_double > 0.1f) {
            sqrt_double = 0.1f;
        }
        if (!this.onGround || this.health <= 0) {
            sqrt_double = 0.0f;
        }
        if (this.onGround || this.health <= 0) {
            n = 0.0f;
        }
        this.cameraYaw += (sqrt_double - this.cameraYaw) * 0.4f;
        this.cameraPitch += (n - this.cameraPitch) * 0.8f;
        final List entitiesWithinAABBExcludingEntity;
        if (this.health > 0 && (entitiesWithinAABBExcludingEntity = this.worldObj.getEntitiesWithinAABBExcludingEntity(this, this.boundingBox.expand(1.0f, 0.0f, 1.0f))) != null) {
            for (int j = 0; j < entitiesWithinAABBExcludingEntity.size(); ++j) {
                ((Entity)entitiesWithinAABBExcludingEntity.get(j)).onCollideWithPlayer(this);
            }
        }
    }
    
    @Override
    public final void onDeath(final Entity entity) {
        this.setSize(0.2f, 0.2f);
        this.setPosition(this.posX, this.posY, this.posZ);
        this.motionY = 0.1f;
        if (entity != null) {
            this.motionX = -MathHelper.cos((this.attackedAtYaw + this.rotationYaw) * 3.1415927f / 180.0f) * 0.1f;
            this.motionZ = -MathHelper.sin((this.attackedAtYaw + this.rotationYaw) * 3.1415927f / 180.0f) * 0.1f;
        }
        else {
            final double n = 0.0f;
            this.motionZ = n;
            this.motionX = n;
        }
        this.yOffset = 0.1f;
    }
    
    @Override
    public final void setEntityDead() {
    }
    
    public final void dropPlayerItem(final ItemStack itemStack) {
        this.dropPlayerItemWithRandomChoice(itemStack, false);
    }
    
    public final void dropPlayerItemWithRandomChoice(final ItemStack itemStack, final boolean boolean2) {
        if (itemStack == null) {
            return;
        }
        final EntityItem entity;
        (entity = new EntityItem(this.worldObj, this.posX, this.posY - 0.3f, this.posZ, itemStack)).delayBeforeCanPickup = 40;
        entity.motionX = -MathHelper.sin(this.rotationYaw / 180.0f * 3.1415927f) * MathHelper.cos(this.rotationPitch / 180.0f * 3.1415927f) * 0.3f;
        entity.motionZ = MathHelper.cos(this.rotationYaw / 180.0f * 3.1415927f) * MathHelper.cos(this.rotationPitch / 180.0f * 3.1415927f) * 0.3f;
        entity.motionY = -MathHelper.sin(this.rotationPitch / 180.0f * 3.1415927f) * 0.3f + 0.1f;
        final double n = this.rand.nextDouble() * 3.1415927f * 2.0f;
        final double n2 = 0.02f * this.rand.nextDouble();
        final EntityItem entityItem = entity;
        entityItem.motionX += (double)(Math.cos((double)n) * n2);
        final EntityItem entityItem2 = entity;
        entityItem2.motionY += (this.rand.nextDouble() - this.rand.nextDouble()) * 0.1f;
        final EntityItem entityItem3 = entity;
        entityItem3.motionZ += (double)(Math.sin((double)n) * n2);
        this.worldObj.entityJoinedWorld(entity);
    }
    
    public final boolean canHarvestBlock(final Block block) {
        final InventoryPlayer inventory = this.inventory;
        final ItemStack stackInSlot;
        return (block.blockMaterial != Material.rock && block.blockMaterial != Material.iron) || ((stackInSlot = inventory.getStackInSlot(inventory.currentItem)) != null && Item.itemsList[stackInSlot.itemID].canHarvestBlock(block));
    }
    
    @Override
    protected void readEntityFromNBT(final NBTTagCompound nbtTagCompound) {
        super.readEntityFromNBT(nbtTagCompound);
    }
    
    @Override
    protected void writeEntityToNBT(final NBTTagCompound nbtTagCompound) {
        super.writeEntityToNBT(nbtTagCompound);
    }
    
    @Override
    protected String getEntityString() {
        return null;
    }
    
    public void displayGUIChest(final IInventory iInventory) {
    }
    
    public void displayWorkbenchGUI() {
    }
    
    public void onItemPickup(final Entity entity) {
    }
    
    @Override
    protected final double getEyeHeight() {
        return 0.12f;
    }
    
    @Override
    public final boolean attackEntityFrom(final Entity entity, int integer) {
        if (!this.worldObj.survivalWorld) {
            return false;
        }
        this.entityAge = 0;
        if (this.health <= 0) {
            return false;
        }
        if (this.heartsLife > this.heartsHalvesLife / 2.0f) {
            return false;
        }
        if (entity instanceof EntityMonster || entity instanceof EntityArrow) {
            if (this.worldObj.difficultySetting == 0) {
                integer = 0;
            }
            if (this.worldObj.difficultySetting == 1) {
                integer = integer / 3 + 1;
            }
            if (this.worldObj.difficultySetting == 3) {
                integer = integer * 3 / 2;
            }
        }
        int n = 25 - this.inventory.getPlayerArmorValue();
        n = integer * n + this.swingProgressInt;
        final InventoryPlayer inventory = this.inventory;
        final int integer2 = integer;
        final InventoryPlayer inventoryPlayer = inventory;
        for (int i = 0; i < inventoryPlayer.armorInventory.length; ++i) {
            if (inventoryPlayer.armorInventory[i] != null && inventoryPlayer.armorInventory[i].getItem() instanceof ItemArmor) {
                inventoryPlayer.armorInventory[i].damageItem(integer2);
                if (inventoryPlayer.armorInventory[i].stackSize == 0) {
                    inventoryPlayer.armorInventory[i] = null;
                }
            }
        }
        integer = n / 25;
        this.swingProgressInt = n % 25;
        return integer != 0 && super.attackEntityFrom(entity, integer);
    }
    
    public void displayGUIFurnace(final TileEntityFurnace furnace) {
    }
}
