package net.minecraft.game.entity.player;

import net.minecraft.game.item.ItemArmor;
import net.minecraft.game.item.ItemStack;
import net.minecraft.client.inventory.IInventory;

public final class InventoryPlayer implements IInventory {
    public ItemStack[] mainInventory;
    public ItemStack[] armorInventory;
    public int currentItem;
    private EntityPlayer player;
    
    public InventoryPlayer(final EntityPlayer entityPlayer) {
        this.mainInventory = new ItemStack[36];
        this.armorInventory = new ItemStack[4];
        this.currentItem = 0;
        this.player = entityPlayer;
    }
    
    public final ItemStack getCurrentItem() {
        return this.mainInventory[this.currentItem];
    }
    
    private int getInventorySlotContainItem(final int integer) {
        for (int i = 0; i < this.mainInventory.length; ++i) {
            if (this.mainInventory[i] != null && this.mainInventory[i].itemID == integer) {
                return i;
            }
        }
        return -1;
    }
    
    private int storeItemStack() {
        for (int i = 0; i < this.mainInventory.length; ++i) {
            if (this.mainInventory[i] == null) {
                return i;
            }
        }
        return -1;
    }
    
    public final void getFirstEmptyStack(int integer) {
        if ((integer = this.getInventorySlotContainItem(integer)) >= 0 && integer < 9) {
            this.currentItem = integer;
        }
    }
    
    public final boolean consumeInventoryItem(int integer) {
        if ((integer = this.getInventorySlotContainItem(integer)) < 0) {
            return false;
        }
        final ItemStack itemStack = this.mainInventory[integer];
        if (--itemStack.stackSize <= 0) {
            this.mainInventory[integer] = null;
        }
        return true;
    }
    
    public final boolean storePartialItemStack(final ItemStack itemStack) {
        if (itemStack.itemDamage == 0) {
            int i = itemStack.itemID;
            int i2 = itemStack.stackSize;
            int i3 = 0;
            while (true) {
                if (i3 < this.mainInventory.length) {
                    if (this.mainInventory[i3] != null && this.mainInventory[i3].itemID == i && this.mainInventory[i3].stackSize < this.mainInventory[i3].getItem().getItemStackLimit() && this.mainInventory[i3].stackSize < 64) {
                        break;
                    }
                    i3++;
                } else {
                    i3 = -1;
                    break;
                }
            }
            int f = i3 < 0 ? storeItemStack() : i3;
            if (f >= 0) {
                if (this.mainInventory[f] == null) {
                    this.mainInventory[f] = new ItemStack(i, 0);
                }
                int c = i2 > this.mainInventory[f].getItem().getItemStackLimit() - this.mainInventory[f].stackSize ? this.mainInventory[f].getItem().getItemStackLimit() - this.mainInventory[f].stackSize : i2;
                if (c > 64 - this.mainInventory[f].stackSize) {
                    c = 64 - this.mainInventory[f].stackSize;
                }
                if (c != 0) {
                    i2 -= c;
                    ItemStack kVar2 = this.mainInventory[f];
                    kVar2.stackSize = c + kVar2.stackSize;
                    this.mainInventory[f].animationsToGo = 5;
                }
            }
            itemStack.stackSize = i2;
            if (itemStack.stackSize == 0) {
                return true;
            }
        }
        final int storeItemStack2;
        if ((storeItemStack2 = this.storeItemStack()) >= 0) {
            this.mainInventory[storeItemStack2] = itemStack;
            this.mainInventory[storeItemStack2].animationsToGo = 5;
            return true;
        }
        return false;
    }
    
    public final ItemStack decrStackSize(int integer1, final int integer2) {
        ItemStack[] array = this.mainInventory;
        if (integer1 >= this.mainInventory.length) {
            array = this.armorInventory;
            integer1 -= this.mainInventory.length;
        }
        if (array[integer1] == null) {
            return null;
        }
        if (array[integer1].stackSize <= integer2) {
            final ItemStack itemStack = array[integer1];
            array[integer1] = null;
            return itemStack;
        }
        final ItemStack splitStack = array[integer1].splitStack(integer2);
        if (array[integer1].stackSize == 0) {
            array[integer1] = null;
        }
        return splitStack;
    }
    
    public final void setInventorySlotContents(int integer, final ItemStack itemStack) {
        ItemStack[] array = this.mainInventory;
        if (integer >= this.mainInventory.length) {
            array = this.armorInventory;
            integer -= this.mainInventory.length;
        }
        array[integer] = itemStack;
    }
    
    public final int getSizeInventory() {
        return this.mainInventory.length + 4;
    }
    
    public final ItemStack getStackInSlot(int integer) {
        ItemStack[] array = this.mainInventory;
        if (integer >= this.mainInventory.length) {
            array = this.armorInventory;
            integer -= this.mainInventory.length;
        }
        return array[integer];
    }
    
    public final String getInvName() {
        return "Inventory";
    }
    
    public final int getInventoryStackLimit() {
        return 64;
    }
    
    public final int getPlayerArmorValue() {
        int n = 0;
        int n2 = 0;
        int n3 = 0;
        for (int i = 0; i < this.armorInventory.length; ++i) {
            if (this.armorInventory[i] != null && this.armorInventory[i].getItem() instanceof ItemArmor) {
                int n4 = this.armorInventory[i].isItemStackDamageable();
                int itemDamage = this.armorInventory[i].itemDamage;
                itemDamage = n4 - itemDamage;
                n2 += itemDamage;
                n3 += n4;
                n4 = ((ItemArmor)this.armorInventory[i].getItem()).damageReduceAmount;
                n += n4;
            }
        }
        if (n3 == 0) {
            return 0;
        }
        return (n - 1) * n2 / n3 + 1;
    }
}
